<template>
  <div class="info-track">
    <div class="header">
      <div class="title">
        <span class="name">{{ title }}</span>
      </div>
    </div>
    <div class="content">
      <van-field
        readonly
        clickable
        label="开始时间"
        :value="startTimeFormat"
        placeholder="选择开始时间"
        right-icon="calendar-o"
        @click="showStartTimePicker = true"
      />
      <van-popup v-model="showStartTimePicker" round position="bottom" @open="onOpenStartTimePopup">
        <van-datetime-picker
          v-model="startTime"
          type="datetime"
          title="选择开始时间"
          :max-date="startTimeMax"
          @confirm="onStartTimeConfirm"
          @cancel="showStartTimePicker = false"
        />
      </van-popup>
      <van-field
        readonly
        clickable
        label="结束时间"
        :value="endTimeFormat"
        right-icon="calendar-o"
        placeholder="选择结束时间"
        @click="showEndTimePicker = true"
      />
      <van-popup v-model="showEndTimePicker" round position="bottom" @open="onOpenEndTimePopup">
        <van-datetime-picker
          v-model="endTime"
          type="datetime"
          title="选择结束时间"
          :min-date="startTime"
          @confirm="onEndTimeConfirm"
          @cancel="showEndTimePicker = false"
        />
      </van-popup>
      <van-row class="rows-btn" type="flex" justify="center" gutter="15">
        <van-col span="6">
          <van-button
            class="btn-speed"
            :class="[speed === 1 ? 'btn-speed-active' : '']"
            plain
            type="default"
            @click="setSpeed(1)"
          >
            x 1
          </van-button>
        </van-col>
        <van-col span="6">
          <van-button
            class="btn-speed"
            :class="[speed === 2 ? 'btn-speed-active' : '']"
            plain
            type="default"
            @click="setSpeed(2)"
          >
            x 2
          </van-button>
        </van-col>
        <van-col span="6">
          <van-button
            class="btn-speed"
            :class="[speed === 5 ? 'btn-speed-active' : '']"
            plain
            type="default"
            @click="setSpeed(5)"
          >
            x 5
          </van-button>
        </van-col>
      </van-row>
      <div class="play-btn">
        <i class="item btn btn-prev" @click="backStep"></i>
        <i class="item btn btn-start" @click="startMove"></i>
        <i class="item btn btn-next" @click="nextStep"></i>
        <span class="item bar"></span>
        <i class="item btn btn-end" @click="stopAnimation"></i>
        <i class="item btn btn-reset" @click="refresh"></i>
      </div>
      <van-row class="rows-btn" type="flex" justify="center" gutter="15">
        <van-col span="6">
          <van-button class="btn-footer" plain type="danger" @click="endTrack"> 结束轨迹播放 </van-button>
        </van-col>
        <van-col span="6">
          <van-button class="btn-footer" type="info" @click="search">开始查询</van-button>
        </van-col>
        <van-col span="6">
          <van-button class="btn-footer" plain type="info" @click="trackList">查看详情</van-button>
        </van-col>
      </van-row>
    </div>
  </div>
</template>

<script>
import dayjs from "dayjs";
import { Field, Popup, DatetimePicker, Col, Row, Button, Notify } from "vant";
import { getEmployeesTrack } from "@/api/employee-controller";

export default {
  name: "infoTrack",
  components: {
    [Field.name]: Field,
    [Popup.name]: Popup,
    [DatetimePicker.name]: DatetimePicker,
    [Col.name]: Col,
    [Row.name]: Row,
    [Button.name]: Button,
    [Notify.name]: Notify,
  },
  props: {
    data: Object,
  },
  data() {
    return {
      showStartTimePicker: false,
      startTime: "",
      startTimeFormat: "",
      startTimeMax: new Date(),
      showEndTimePicker: false,
      endTime: "",
      endTimeFormat: "",
      endTimeMin: new Date(),
      speed: 1,
      marketList: [],
      currentIndex: null,
      lineArr: [],
    };
  },
  computed: {
    title() {
      return `历史轨迹：${this.data?.name || ""}`;
    },
  },
  methods: {
    onOpenStartTimePopup() {
      if (!this.startTime) {
        this.startTime = new Date();
      }
      this.startTimeMax = this.endTime
        ? this.endTime
        : this.startTime
        ? dayjs(this.startTime).add(10, "y").toDate()
        : dayjs().add(10, "y").toDate();
    },
    onStartTimeConfirm() {
      this.startTimeFormat = dayjs(this.startTime).format("YYYY-MM-DD HH:mm:ss");
      this.showStartTimePicker = false;
    },
    onOpenEndTimePopup() {
      if (!this.endTime) {
        this.endTime = new Date();
      }
      this.endTimeMin = this.startTime
        ? this.startTime
        : this.endTime
        ? dayjs(this.endTime).subtract(10, "y").toDate()
        : dayjs().subtract(10, "y").toDate();
    },
    onEndTimeConfirm() {
      this.endTimeFormat = dayjs(this.endTime).format("YYYY-MM-DD HH:mm:ss");
      this.showEndTimePicker = false;
    },
    setSpeed(speed) {
      this.speed = speed;
      this.startMove();
    },
    search() {
      console.log("searching...", this.data);
      let params = {
        employeeId: this.data.id,
        beginDate: this.startTimeFormat,
        endDate: this.endTimeFormat,
      };
      getEmployeesTrack(params)
        .then((res) => {
          if (res && res.length > 0) {
            this.marketList = res;
            console.log(this.marketList);
            const pathData = this.marketList.map((path) => {
              return {
                position: [path.longitude, path.latitude],
                time: dayjs(path.createdTime).format("YYYY-MM-DD HH:mm:ss"),
                duration: 10000,
              };
            });
            this.$emit("setTrack", pathData);
            this.setCurrentRow(0);
          } else {
            Notify({ type: "danger", message: "暂无轨迹" });
          }
        })
        .catch((err) => {
          console.log(err);
          Notify({ type: "danger", message: err.response.data.message });
        });
    },
    startMove() {
      this.$emit("startMove", this.speed);
    },
    backStep() {
      this.$emit("backStep");
    },
    nextStep() {
      this.$emit("nextStep");
    },
    stopAnimation() {
      this.$emit("pauseMove");
    },
    refresh() {
      this.$emit("refresh", this.speed);
    },
    setCurrentRow(index) {
      this.currentIndex = index;
    },
    endTrack() {
      this.$emit("cancel");
    },
    trackList() {
      this.$emit("trackList", this.marketList);
    },
  },
};
</script>

<style scoped lang="less">
.info-track {
  .header {
    width: 100%;
    height: 52px;
    background: #ffffff;
    padding: 0 20px;
    box-sizing: border-box;
    display: flex;
    align-items: center;
    //justify-content: space-between;
    .title {
      display: flex;
      align-items: center;
      .name {
        font-size: 14px;
        font-family: PingFang SC-Medium, PingFang SC, serif;
        font-weight: 500;
        color: #303133;
        line-height: 22px;
        margin-left: 8px;
      }
    }
  }
  .content {
    .rows-btn {
      padding: 20px 0;
      .btn-speed {
        width: 81px;
        height: 28px;
        border-radius: 4px 4px 4px 4px;
        font-size: 14px;
        font-family: PingFang SC-Medium, PingFang SC, serif;
        font-weight: 500;
        color: #666666;
        line-height: 22px;
        &-active {
          background: rgba(22, 119, 255, 0.1);
          border: 1px solid #1677ff;
          color: #1677ff;
        }
      }
      .btn-footer {
        width: 88px;
        height: 26px;
        border-radius: 6px 6px 6px 6px;
        font-size: 12px;
        padding: 0;
      }
    }
    .play-btn {
      height: 32px;
      padding-left: 52px;
      //margin-bottom: 24px;
      display: flex;
      align-items: center;
      justify-content: flex-start;
      .item {
        margin-right: 22px;
        &:last-child {
          margin-right: 0;
        }
      }
      .bar {
        display: block;
        width: 1px;
        height: 100%;
        background: #d9d9d9;
      }
      .btn {
        width: 32px;
        height: 32px;
        &-prev {
          background: url("~@/assets/images/common/快进左.png") no-repeat;
          background-size: 100% 100%;
        }
        &-prev:active {
          opacity: 0.5;
        }
        &-start {
          background: url("~@/assets/images/common/播放.png") no-repeat;
          background-size: 100% 100%;
        }
        &-start:active {
          opacity: 0.5;
        }
        &-next {
          background: url("~@/assets/images/common/快进右.png") no-repeat;
          background-size: 100% 100%;
        }
        &-next:active {
          opacity: 0.5;
        }
        &-end {
          background: url("~@/assets/images/common/暂停.png") no-repeat;
          background-size: 100% 100%;
        }
        &-end:active {
          opacity: 0.5;
        }
        &-reset {
          background: url("~@/assets/images/common/刷新.png") no-repeat;
          background-size: 100% 100%;
        }
        &-reset:active {
          opacity: 0.5;
        }
        ::after {
          background-size: 150% 150%;
        }
        &-after:active {
          opacity: 0.5;
        }
      }
    }
  }
}
</style>
